#!/usr/bin/perl

use strict;
use warnings;
use LWP::Simple;

sub print_status ($$$) {
	my ($status, $name, $description) = @_;

	print "<module>\n";
	print "<name>$name</name>\n";
	print "<type>generic_proc</type>\n";
	print "<data>$status</data>\n";
	print "<description>$description</description>\n";
	print "</module>\n";
}

sub print_data ($$$) {
	my ($data, $name, $description) = @_;

	print "<module>\n";
	print "<name>$name</name>\n";
	print "<type>generic_data</type>\n";
	print "<data>$data</data>\n";
	print "<description>$description</description>\n";
	print "</module>\n";
}


sub execution_error () {

	print_status (0, "StreamPulse_ERROR", "cannot connect");
	exit -1;

}

if ($#ARGV < 1 ){
	print_status (0, "StreamPulse_ERROR", "Missing parameters in plugin");
	exit -1;
}

my $URL = $ARGV[0];
my $module_name = $ARGV[1];

my $reply = get ($URL) or execution_error;

# Step 1. Check [200] message, any other is FAIL.

if ($reply =~ /^\[200\]/){
	print_status (1, $module_name."_status", "Streaming connection is OK");
} else {
    print_status (0, $module_name."_status", "Streaming connection IS NOT OK");
}

# Step 2. Bytes loaded ( BytesLoaded: [129444] )
if ($reply =~ /BytesLoaded: \[([0-9]*)\]/){
	print_data ($1, $module_name."_BytesLoaded", "Bytes loaded in this connection");
}

# Step 3. CurrentTime: [0.747])
if ($reply =~ /CurrentTime\:\s\[([\.0-9]*)\]/){
	print_data ($1, $module_name."_PlayingTime", "Time used to check stream");
}

exit 0;